@@ -1,5 +1,6 @@
 class Loop:
     """Django template like loop object."""
+
     def __init__(self, iterable):
         self.iterable = enumerate(iterable)
         self.length = len(iterable)
@@ -33,3 +34,14 @@ def isiterable(obj):
     except TypeError:
         return False
     return True
+
+
+def contain_any(iterable, elements):
+    """
+    Return `True` if any of the `elements` are contained in the `iterable`,
+    `False` otherwise.
+    """
+    for e in elements:
+        if e in iterable:
+            return True
+    return False
